@@ -23,21 +23,22 @@
 #ifndef SPELL_DICTIONARY_H_
 #define SPELL_DICTIONARY_H_
 
-#include <libgnome/gnome-defs.h>
-#include <bonobo/bonobo-object.h>
-#include <pspell/pspell.h>
+G_BEGIN_DECLS
 
-BEGIN_GNOME_DECLS
+#include <bonobo/bonobo-object.h>
+#include <aspell.h>
 
 #define GNOME_SPELL_DICTIONARY_TYPE        (gnome_spell_dictionary_get_type ())
-#define GNOME_SPELL_DICTIONARY(o)          (GTK_CHECK_CAST ((o),       GNOME_SPELL_DICTIONARY_TYPE, GNOMESpellDictionary))
-#define GNOME_SPELL_DICTIONARY_CLASS(k)    (GTK_CHECK_CLASS_CAST((k),  GNOME_SPELL_DICTIONARY_TYPE, GNOMESpellDictionaryClass))
-#define IS_GNOME_SPELL_DICTIONARY(o)       (GTK_CHECK_TYPE ((o),       GNOME_SPELL_DICTIONARY_TYPE))
-#define IS_GNOME_SPELL_DICTIONARY_CLASS(k) (GTK_CHECK_CLASS_TYPE ((k), GNOME_SPELL_DICTIONARY_TYPE))
+#define GNOME_SPELL_DICTIONARY(o)          (G_TYPE_CHECK_INSTANCE_CAST ((o), \
+									GNOME_SPELL_DICTIONARY_TYPE, GNOMESpellDictionary))
+#define GNOME_SPELL_DICTIONARY_CLASS(k)    (G_TYPE_CHECK_CLASS_CAST((k), \
+								    GNOME_SPELL_DICTIONARY_TYPE, GNOMESpellDictionaryClass))
+#define IS_GNOME_SPELL_DICTIONARY(o)       (G_TYPE_CHECK_INSTANCE_TYPE ((o), GNOME_SPELL_DICTIONARY_TYPE))
+#define IS_GNOME_SPELL_DICTIONARY_CLASS(k) (G_TYPE_CHECK_CLASS_TYPE ((k), GNOME_SPELL_DICTIONARY_TYPE))
 
 typedef struct {
-	PspellConfig  *config;
-	PspellManager *manager;
+	AspellConfig  *config;
+	AspellSpeller *speller;
 	gboolean       changed;
 } SpellEngine;
 
@@ -46,10 +47,13 @@ typedef struct {
 
 	gboolean changed;
 	GSList *engines;
+	GHashTable *languages;
+	GHashTable *engines_ht;
 } GNOMESpellDictionary;
 
 typedef struct {
 	BonoboObjectClass parent_class;
+	POA_GNOME_Spell_Dictionary__epv epv;
 } GNOMESpellDictionaryClass;
 
 GtkType                          gnome_spell_dictionary_get_type   (void);
@@ -58,6 +62,6 @@ GNOMESpellDictionary            *gnome_spell_dictionary_construct  (GNOMESpellDi
 BonoboObject                    *gnome_spell_dictionary_new        (void);
 POA_GNOME_Spell_Dictionary__epv *gnome_spell_dictionary_get_epv    (void);
 
-END_GNOME_DECLS
+G_END_DECLS
 
 #endif
